import java.awt.Color;
import java.util.*;

// Represents a mathmatical graph, displaying points of differing colors added by a user
public class MultiGraph extends ColorGraph {
    private Map<Graphable, Color> elements;

    // Behavior: Creates a new, empty graph displaying 2d space from
    //           [-10, 10] on each axis
    public MultiGraph() {
        this.elements = new HashMap<>();
    }

    // Behavior: Adds the given graphical element 'g' to be displayed within this graph
    //           with default color Color.RED
    // Parameters:
    //      g - The element to be added
    @Override
    public void add(Graphable g) {
        this.add(g, Color.RED);
    }

    // Behavior: Adds the given graphical element 'g' to be displayed within this graph
    //           with provided Color 'c'
    // Parameters:
    //      g - The 2d point to be added
    //      c - The Color to make the point
    @Override
    public void add(Graphable g, Color c) {
        this.elements.put(g, c);
    }

    // Behavior: Returns the color of the provided graphable 'g', null if not present
    @Override
    public Color getColor(Graphable g) {
        return this.elements.get(g);
    }

    // Behavior: Returns a set of all the elements present in this graph
    @Override
    public Set<Graphable> getElements() {
        return this.elements.keySet();
    }
}
