// This class represents a 2-dimensional cartesian point
public class Point implements Graphable, Comparable<Point> {
    private int x;
    private int y;

    // Constructs a point at the origin (0, 0)
    public Point() {
        this(0, 0);
    }

    // Constructs a point with the provided 'x' and 'y' values
    public Point(int x, int y) {
        this.x = x;
        this.y = y;
    }

    // Returns the x-coordinate of this point
    public int getX() {
        return this.x;
    }

    // Returns the y-coordinate of this point
    public int getY() {
        return this.y;
    }

    // Returns the distance from this Point to the provided 'other' Point
    public double distanceTo(Point other) {
        return Math.sqrt(Math.pow(this.x - other.x, 2) +
                         Math.pow(this.y - other.y, 2));
    }

    // Updates the location of this point to the provided 'x' and 'y' values
    public void setLocation(int x, int y) {
        this.x = x;
        this.y = y;
    }

    // Compares this Point to 'other', sorting based on x-values (increasing)
    @Override
    public int compareTo(Point other) {
        return this.x - other.x;
    }

    // Returns whether or not this Point is equal to the provided 'other' Object
    @Override
    public boolean equals(Object other) {
        if (other == null || !(other instanceof Point)) {
            return false;
        } else {
            Point otherPoint = (Point)other;
            return otherPoint.x == this.x &&
                   otherPoint.y == this.y;
        }
    }

    // Returns a string representation of this Point
    @Override
    public String toString() {
        return "(" + x + ", " + y + ")";
    }
}
